@@ -5,11 +5,14 @@ from chargebee import APIError
 
 class CreditNote(Model):
     class LineItem(Model):
-      fields = ["id", "date_from", "date_to", "unit_amount", "quantity", "is_taxed", "tax_amount", "tax_rate", "amount", "discount_amount", "item_level_discount_amount", "description", "entity_type", "tax_exempt_reason", "entity_id"]
+      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "is_taxed", "tax_amount", "tax_rate", "amount", "discount_amount", "item_level_discount_amount", "description", "entity_type", "tax_exempt_reason", "entity_id"]
       pass
     class Discount(Model):
       fields = ["amount", "description", "entity_type", "entity_id"]
       pass
+    class LineItemDiscount(Model):
+      fields = ["line_item_id", "discount_type", "coupon_id", "discount_amount"]
+      pass
     class Tax(Model):
       fields = ["name", "amount", "description"]
       pass
@@ -26,8 +29,8 @@ class CreditNote(Model):
     fields = ["id", "customer_id", "subscription_id", "reference_invoice_id", "type", "reason_code", \
     "status", "vat_number", "date", "price_type", "currency_code", "total", "amount_allocated", \
     "amount_refunded", "amount_available", "refunded_at", "voided_at", "resource_version", "updated_at", \
-    "sub_total", "line_items", "discounts", "taxes", "line_item_taxes", "linked_refunds", "allocations", \
-    "deleted"]
+    "sub_total", "line_items", "discounts", "line_item_discounts", "taxes", "line_item_taxes", "linked_refunds", \
+    "allocations", "deleted"]
 
 
     @staticmethod
